==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/GridColumnSortOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnSortOptionsDescription } from "./GridColumnSortOptionsDescription";
/**
 * @hidden
 */
var GridColumnSortOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnSortOptionsDescriptionMetadata, _super);
    function GridColumnSortOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnSortOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnSortOptionsDescriptionMetadata.a == null) {
            GridColumnSortOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnSortOptionsDescriptionMetadata.c(GridColumnSortOptionsDescriptionMetadata.a);
        }
        if (a.g(GridColumnSortOptionsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridColumnSortOptionsDescriptionMetadata.a);
    };
    GridColumnSortOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        a.item("AscendingCaption", "String");
        a.item("DescendingCaption", "String");
        a.item("SortDirection", "ExportedType:string:ColumnSortDirection");
        a.item("SortDirection@names", "None;Ascending;Descending");
    };
    GridColumnSortOptionsDescriptionMetadata.d = function (a) {
        GridColumnSortOptionsDescriptionMetadata.b(a);
        a.u("GridColumnSortOptions", function () { return new GridColumnSortOptionsDescription(); });
        a.t("GridColumnSortOptions", GridColumnSortOptionsDescriptionMetadata.a);
    };
    GridColumnSortOptionsDescriptionMetadata.$t = markType(GridColumnSortOptionsDescriptionMetadata, 'GridColumnSortOptionsDescriptionMetadata');
    GridColumnSortOptionsDescriptionMetadata.a = null;
    return GridColumnSortOptionsDescriptionMetadata;
}(Base));
export { GridColumnSortOptionsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/GridColumnSortOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnSortOptionsDescription } from "./GridColumnSortOptionsDescription";
/**
 * @hidden
 */
var GridColumnSortOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnSortOptionsDescriptionMetadata, _super);
    function GridColumnSortOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnSortOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnSortOptionsDescriptionMetadata.a == null) {
            GridColumnSortOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnSortOptionsDescriptionMetadata.c(GridColumnSortOptionsDescriptionMetadata.a);
        }
        if (a.j(GridColumnSortOptionsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnSortOptionsDescriptionMetadata.a);
    };
    GridColumnSortOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        a.item("AscendingCaption", "String");
        a.item("DescendingCaption", "String");
        a.item("SortDirection", "ExportedType:string:ColumnSortDirection");
        a.item("SortDirection@names", "None;Ascending;Descending");
    };
    GridColumnSortOptionsDescriptionMetadata.d = function (a) {
        GridColumnSortOptionsDescriptionMetadata.b(a);
        a.aa("GridColumnSortOptions", function () { return new GridColumnSortOptionsDescription(); });
        a.z("GridColumnSortOptions", GridColumnSortOptionsDescriptionMetadata.a);
    };
    GridColumnSortOptionsDescriptionMetadata.$t = markType(GridColumnSortOptionsDescriptionMetadata, 'GridColumnSortOptionsDescriptionMetadata');
    GridColumnSortOptionsDescriptionMetadata.a = null;
    return GridColumnSortOptionsDescriptionMetadata;
}(Base));
export { GridColumnSortOptionsDescriptionMetadata };
